@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from orionis.services.introspection.dependencies.entities.resolve_argument import ResolveArguments
 
 class IReflectionCallable(ABC):
     """
@@ -156,7 +157,7 @@ class IReflectionCallable(ABC):
         pass
 
     @abstractmethod
-    def getDependencies(self):
+    def getDependencies(self) -> ResolveArguments:
         """
         Analyze the callable and retrieve its dependency information.
 
@@ -166,7 +167,7 @@ class IReflectionCallable(ABC):
 
         Returns
         -------
-        CallableDependency
+        ResolveArguments
             An object containing information about the callable's dependencies:
             - resolved : dict
                 A dictionary mapping parameter names to their resolved values
